<?php $TRANSLATIONS = array(
"Save" => "Opslaan",
"Search:" => "Zoeken:",
"Close" => "Sluiten",
"Next" => "Volgende",
"Clear" => "Opschonen",
"Saving..." => "Opslaan",
"Failed to save file" => "Bewaren mislukt",
"An error occurred!" => "Er is iets fout gegaan!",
"There were unsaved changes, click here to go back" => "Er zijn niet opgeslagen veranderingen, klik hier of ga terug"
);
